package
Version:
v0.0.0-...-b8bfb19
Opens a new window with list of versions in this module.
Published: Jul 25, 2024
License: MIT
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
README
¶
Documentation
¶
func PopAll(dest_id int32) []IPCObject
---------------------------------------------------------- pop all message for dest user
func Push(req *IPCObject) bool
---------------------------------------------------------- push an ipc object to db
Source Files
¶
Click to show internal directories.
Click to hide internal directories.